==> vala-0.1.4.tar.bz2: vala-0.1.4/vala/valacodebinding.h <==
/* valacodebinding.vala
 *
 * Copyright (C) 2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALACODEBINDING_H__
#define __VALA_VALACODEBINDING_H__

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS


#define VALA_TYPE_CODE_BINDING (vala_code_binding_get_type ())
#define VALA_CODE_BINDING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_BINDING, ValaCodeBinding))
#define VALA_CODE_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_BINDING, ValaCodeBindingClass))
#define VALA_IS_CODE_BINDING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_BINDING))
#define VALA_IS_CODE_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_BINDING))
#define VALA_CODE_BINDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_BINDING, ValaCodeBindingClass))

typedef struct _ValaCodeBinding ValaCodeBinding;
typedef struct _ValaCodeBindingClass ValaCodeBindingClass;
typedef struct _ValaCodeBindingPrivate ValaCodeBindingPrivate;

/**
 * The link between a source code node and generated code.
 */
struct _ValaCodeBinding {
	GObject parent;
	ValaCodeBindingPrivate * priv;
};
struct _ValaCodeBindingClass {
	GObjectClass parent;
	void (*emit) (ValaCodeBinding* self);
};

void vala_code_binding_emit (ValaCodeBinding* self);
GType vala_code_binding_get_type (void);

G_END_DECLS

#endif

==> vala-0.3.1.tar.bz2: vala-0.3.1/vala/valacodebinding.h <==
/* valacodebinding.vala
 *
 * Copyright (C) 2007-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALACODEBINDING_H__
#define __VALA_VALACODEBINDING_H__

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS


#define VALA_TYPE_CODE_BINDING (vala_code_binding_get_type ())
#define VALA_CODE_BINDING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CODE_BINDING, ValaCodeBinding))
#define VALA_CODE_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CODE_BINDING, ValaCodeBindingClass))
#define VALA_IS_CODE_BINDING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CODE_BINDING))
#define VALA_IS_CODE_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CODE_BINDING))
#define VALA_CODE_BINDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CODE_BINDING, ValaCodeBindingClass))

typedef struct _ValaCodeBinding ValaCodeBinding;
typedef struct _ValaCodeBindingClass ValaCodeBindingClass;
typedef struct _ValaCodeBindingPrivate ValaCodeBindingPrivate;

/**
 * The link between a source code node and generated code.
 */
struct _ValaCodeBinding {
	GObject parent_instance;
	ValaCodeBindingPrivate * priv;
};
struct _ValaCodeBindingClass {
	GObjectClass parent_class;
};

ValaCodeBinding* vala_code_binding_new (void);
GType vala_code_binding_get_type (void);


G_END_DECLS

#endif
